.. _spkg_pkgconf:

pkgconf: An implementation of the pkg-config spec
=================================================

Description
-----------

Pkgconf is an implementation of the pkg-config spec with minimal
dependencies.

License
-------

ISC License (equivalent to Simplified BSD)


Upstream Contact
----------------

https://github.com/pkgconf/pkgconf

Special Update/Build Instructions
---------------------------------

-  install.patch: Use install script from AC_PROG_INSTALL

Pkgconf is used in bzip2, so we must not use the bzip2-compressed
tarball.


Type
----

standard


Dependencies
------------

- :ref:`spkg_patch`
- :ref:`spkg_xz`

Version Information
-------------------

package-version.txt::

    1.8.0

pyproject.toml::

    pkgconfig

See https://repology.org/project/pkgconf/versions, https://repology.org/project/pkg-config/versions

Installation commands
---------------------

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i pkgconf

.. tab:: Arch Linux:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S pkgconf

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install pkg-config

.. tab:: Debian/Ubuntu:

   .. CODE-BLOCK:: bash

       $ sudo apt-get install pkg-config

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install pkg-config

.. tab:: FreeBSD:

   .. CODE-BLOCK:: bash

       $ sudo pkg install devel/pkgconf

.. tab:: Homebrew:

   .. CODE-BLOCK:: bash

       $ brew install pkg-config

.. tab:: MacPorts:

   .. CODE-BLOCK:: bash

       $ sudo port install pkgconfig

.. tab:: openSUSE:

   .. CODE-BLOCK:: bash

       $ sudo zypper install pkgconf

.. tab:: Void Linux:

   .. CODE-BLOCK:: bash

       $ sudo xbps-install pkgconf


If the system package is installed, ``./configure`` will check if it can be used.
